======
 News
======

 0.1.5
-------

*Release date: 3-Dec-2013*

* Bugfix: missing NEWS.rst in manifest

 0.1.4
-------

*Release date: 3-Dec-2013*

* @yoloseem fixed indentation bug
* Fixed setup.cfg parsing of include / exclude directives

 0.1.3
-------

*Release date: 6-Oct-2013*

* Fixed github issue #1: Setting pep8 directives in setup.cfg doesn't work
* Exposed --check-dirs= option to control which modules are checked
* Fixed incorrect handling of stdout/stderr when redirecting pep8 output to a file

 0.1.2
-------

*Release date: 4-Oct-2013*

* Fork of https://github.com/johnnoone/setuptools-lint
* Adds in config parsing from setup.cfg
* Semantic versioning

